@@ -11,6 +11,7 @@ from aiokeydb.connection import (
     SSLConnection,
     UnixDomainSocketConnection,
 )
+from aiokeydb.credentials import CredentialProvider, UsernamePasswordCredentialProvider
 from aiokeydb.exceptions import (
     AuthenticationError,
     AuthenticationWrongNumberOfArgsError,
@@ -56,7 +57,7 @@ from aiokeydb.asyncio import (
 from aiokeydb.client.serializers import SerializerType
 from aiokeydb.client.config import KeyDBSettings
 from aiokeydb.client.schemas.session import KeyDBSession
-from aiokeydb.client.core import KeyDBClient
+from aiokeydb.client.meta import KeyDBClient
 
 if sys.version_info >= (3, 8):
     from importlib import metadata
@@ -108,6 +109,8 @@ __all__ = [
     "TimeoutError",
     "UnixDomainSocketConnection",
     "WatchError",
+    "CredentialProvider",
+    "UsernamePasswordCredentialProvider",
     # Async
     "AsyncKeyDB", 
     "StrictAsyncKeyDB",
